#-
# Copyright 2010 Jason Harmening
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
#

#include <sys/errno.h>
#include <sys/bus.h>
#include <sys/param.h>
#include <sys/lock.h>
#include <sys/mutex.h>
#include "cx88_audio_ioctl.h"

INTERFACE cx88_audio;

CODE {

   static int null_start_capture(device_t dev, uint8_t path)
   {
      return ENXIO;
   }
   
   static void null_stop_capture(device_t dev, uint8_t path)
   {
   }

   static int null_set_mute(device_t dev, uint8_t path, boolean_t mute)
   {
      return ENXIO;
   }

   static boolean_t null_get_mute(device_t dev, uint8_t path)
   {
      return FALSE;
   }

   static int null_set_volume(device_t dev, uint8_t path, cx88_audio_volume vol)
   {
      return ENXIO;
   }
   
   static cx88_audio_volume null_get_volume(device_t dev, uint8_t path)
   {
      static cx88_audio_volume vol = {.in_left = 0, .in_right = 0};
      return vol;
   }
   
   static int null_set_stereo(device_t dev, uint8_t path, boolean_t stereo)
   {
      return ENXIO;
   }
   
   static boolean_t null_get_stereo(device_t dev, uint8_t path)
   {
      return FALSE;
   }
   
   static int null_set_format(device_t dev, uint8_t path, cx88_audio_format *format)
   {
      return ENXIO;
   }
   
   static int null_get_info(device_t dev, uint8_t path, cx88_audio_status *status)
   {
      return ENXIO;
   }
};

# Start audio capture
METHOD int start_capture {
   device_t dev;
   uint8_t path;
} DEFAULT null_start_capture;

# Stop audio capture
METHOD void stop_capture {
   device_t dev;
   uint8_t path;
} DEFAULT null_stop_capture;

# Set muted state of device
METHOD int set_mute {
   device_t dev;
   uint8_t path;
   boolean_t mute;
} DEFAULT null_set_mute;

# Get muted state of device
METHOD boolean_t get_mute {
   device_t dev;
   uint8_t path;
} DEFAULT null_get_mute;

# Set volume/balance
METHOD int set_volume {
   device_t dev;
   uint8_t path;
   cx88_audio_volume vol;
} DEFAULT null_set_volume;

# Get volume/balance
METHOD cx88_audio_volume get_volume {
   device_t dev;
   uint8_t path;
} DEFAULT null_get_volume;

# Set stereo mode
METHOD int set_stereo {
   device_t dev;
   uint8_t path;
   boolean_t stereo;
} DEFAULT null_set_stereo;

# Get stereo mode
METHOD boolean_t get_stereo {
   device_t dev;
   uint8_t path;
} DEFAULT null_get_stereo;

# Set audio standard, stereo mode, SAP, etc.
METHOD int set_format {
   device_t dev;
   uint8_t path;
   cx88_audio_format *format;
} DEFAULT null_set_format;

# Retrieve signal/carrier/volume/etc. status
METHOD int get_info {
   device_t dev;
   uint8_t path;
   cx88_audio_status *status;
} DEFAULT null_get_info;
