/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_CAPTURE_FACTORY_H__
#define __CX88_CAPTURE_FACTORY_H__

#include "cx88_url_capture.h"
#include "cx88_file_capture.h"
#include "cx88_audio_capture.h"
#include "tuner_config.h"

#define CX88_MTU_KEY "mtu"
#define CX88_BUFFER_KEY "buffer"

namespace cx88_capture_factory
{
   static cx88_capture *create(
      const char *name,
      tuner_config &options,
      int &error)
   {
      if (strncmp(name, "oss://", 6) == 0)
      {
         return new cx88_audio_capture(name + 6, error);
      }
      else if (strncmp(name, "file://", 7) == 0)
      {
         return new cx88_file_capture(name + 7, error, options.get_number<size_t>(CX88_BUFFER_KEY, CX88_DEFAULT_FILE_CACHE));
      }
      else
      {
         return new cx88_url_capture(name, error, options.get_number<size_t>(CX88_MTU_KEY, CX88_DEFAULT_MTU));
      }
   }
};

#endif
