/*-
 * Copyright 2008 Konstantin Dimitrov <kosio.dimitrov@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __WINTV_HVR1100_H__
#define __WINTV_HVR1100_H__

#include <sys/errno.h>
#include "fmd1216me.h"
#include "cx22702.h"
#include "cx88_debug.h"
#include "cx88_mpeg_driver.h"
#include "cx88_analog_driver.h"

namespace cx88_mpeg_driver_factory
{
   
   class wintv_hvr1100
      : public cx88_mpeg_driver
   {
      public:
         
         wintv_hvr1100(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            int &error)
            : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error)
         {}
         
         virtual ~wintv_hvr1100(void) {}
         
      protected:
         
         virtual int create_i2c_drivers(void)
         {
            int error = 0;
            m_i2c_devs[1].driver = new cx22702(m_tunerconf, *(m_i2c_devs[1].dev), DVB_INPUT_SERIAL, error);
            m_i2c_devs[0].driver = new fmd1216me(m_tunerconf, *(m_i2c_devs[0].dev));
            if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
            {
               error = ENOMEM;
            }
            if (error)
            {
               CX88ERR << "Error initializing tuner/demodulator driver for WinTV HVR-1100" << std::endl;
               return error;
            }
            return 0;
         }
         
         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[0].driver;
            delete m_i2c_devs[1].driver;  
         }
         
         virtual int create_i2c_devices(void)
         {
            m_i2c_devs[0].conf.in_addr = 0x61;
            m_i2c_devs[1].conf.in_addr = 0x63;
            return 0;
         }

   };
};

namespace cx88_analog_driver_factory
{
   class wintv_hvr1100
      : public cx88_analog_driver
   {
      public:
         
         wintv_hvr1100(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            cx88_analog_mode mode,
            cx88_analog_driver *slave,
            cx88_analog_driver *pip_driver,
            int &error)
            : cx88_analog_driver(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error)
         {}
         
         virtual ~wintv_hvr1100(void) {}
         
      protected:
         
         virtual int create_i2c_drivers(void)
         {
            int error = 0;
            m_i2c_devs[1].driver = new cx22702(m_tunerconf, *(m_i2c_devs[1].dev), DVB_INPUT_SERIAL, error);
            m_i2c_devs[0].driver = new fmd1216me(m_tunerconf, *(m_i2c_devs[0].dev));
            if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
            {
               error = ENOMEM;
            }
            if (m_i2c_devs[0].driver == NULL)
            {
               CX88ERR << "Error initializing tuner driver for WinTV HVR-1100" << std::endl;
            }
            return error;
         }
         
         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[0].driver;
            delete m_i2c_devs[1].driver;  
         }
         
         virtual int create_i2c_devices(void)
         {
            m_i2c_devs[0].conf.in_addr = 0x61;
            m_i2c_devs[0].source_mask = CX88_SOURCE_DEFAULT;
            m_i2c_devs[1].conf.in_addr = 0x63;
            m_i2c_devs[1].source_mask = 0;
            return 0;
         }
   
   };
   
};

#endif

