/*-
 * Copyright 2007 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_MPEG_DRIVER_H__
#define __CX88_MPEG_DRIVER_H__

#include <pthread.h>
#include <sys/ioctl.h>
#include "dvb_driver.h"
#include "cx88_mpeg_ioctl.h"
#include "cx88_driver.h"

class cx88_mpeg_driver
   : public cx88_driver
{
   public:
      
      cx88_mpeg_driver(
         cx88_xml_config &cx88conf,
         tuner_config &tunerconf,
         const char *devnode,
         capvec &captures,
         int &error);
      
      virtual ~cx88_mpeg_driver(void);
      
   protected:
      
      virtual int capture(const std::string &channel_string, cx88_capture_params &params);
            
      virtual int get_info(std::string &info);
      
      virtual double get_signal_strength(void);
      
      virtual int set_channel_options(dvb_channel &channel) 
      {
         return 0;
      }
      
      virtual int set_config_options(cx88_mpeg_config &config) 
      {
         return 0;
      }
      
      virtual int set_capture_options(cx88_mpeg_capture &capture)
      {
         return 0;
      }
      
      int submit_buffer(void *buffer, size_t num_bytes, size_t packet_size = 0);
      
      void init_psfilter(void);
      
      uint16_t get_pid(uint8_t *packet)
      {
         return (((packet[1] & 0x1F) << 8) | packet[2]);
      }
      
      bool process_pat(uint8_t *packet, size_t size);
      
      void process_pmt(uint8_t *packet, size_t size);
      
      static uint32_t crc32(uint8_t *packet, size_t size);
      
   private:
      
      int capture(void *buffer, cx88_mpeg_config &config, cx88_capture_params &params);      
      int change_channel(dvb_interface &ifc, cx88_capture_params &params);
      int get_signal(dvb_signal &signal);
      
      uint16_t m_pmt_pid;
      uint8_t m_pat_version;
      uint8_t m_pmt_version;
      uint8_t m_new_pat_version;
      uint8_t m_packet_offset;
      uint8_t m_last_packet[CX88_MPEG_DEFAULT_PACKET_SIZE];
      bool m_pat_ready;
      bool m_pmt_ready;
      typedef std::vector<uint16_t> program_vec;
      program_vec m_pids;
      program_vec m_programs;

};

#endif
