#include "cx88_mpeg_driver_factory.h"
#include "cx88_cards.h"

#define CX88_ENABLE_MPEG
#include "cx_ref_dvbt.h"
#include "fusion_5gold.h"
#include "pchdtv_hd3000.h"
#include "pchdtv_hd5500.h"
#include "wintv_nova_t.h"
#include "wintv_hvr1100.h"
#include "wintv_hvr1300.h"
#include "wintv_hvr3000.h"
#include "wintv_hvr4000.h"
#include "wintv_hvr1800.h"
#include "wintv_hvr1850.h"
#include "fusion_7dual.h"

cx88_mpeg_driver *cx88_mpeg_driver_factory::create(
   cx88_xml_config &cx88conf,
   tuner_config &tunerconf,
   const char *devnode,
   capvec &captures,
   int &error)
{
   switch (get_card_id(tunerconf, devnode))
   {
      case CX88_CARD_ID_PCHDTV_HD3000:
         return (new pchdtv_hd3000(cx88conf, tunerconf, devnode, captures, error));
      case CX88_CARD_ID_PCHDTV_HD5500:
         return (new pchdtv_hd5500(cx88conf, tunerconf, devnode, captures, error));
      case CX88_CARD_ID_WINTV_NOVA_T:
         return (new wintv_nova_t(cx88conf, tunerconf, devnode, captures, error));
      /* DViCO FusionHDTV 5 Gold, PCI SubVen ID: 0x18ac, PCI SubDev ID: 0xd500 */
      case CX88_CARD_ID_FUSION_5_GOLD:
         return (new fusion_5gold(cx88conf, tunerconf, devnode, captures, error));
      /* Club3D Zap TV2100, PCI SubVen ID: 0x12ab, PCI SubDev ID: 0x2300             */
      /* Conexant Reference DVB-T card, PCI SubVen ID: 0x14f1, PCI SubDev ID: 0x0187 */
      /* Kworld VStream Xpert DVB-T, PCI SubVen ID: 0x17de, PCI SubDev ID: 0x08a1    */
      /* Terratec Cinergy 1400 DVB-T, PCI SubVen ID: 0x153b, PCI SubDev ID: 0x1166   */
      /* Leadtek WinFast DTV1000T, PCI SubVen ID: 0x107d, PCI SubDev ID: 0x665f      */
      case CX88_CARD_ID_CLUB3D_ZAP_TV2100:
      case CX88_CARD_ID_REF_DVBT:
      case CX88_CARD_ID_KWORLD_VSTREAM_XPERT:
      case CX88_CARD_ID_TERRATEC_CINERGY_1400:
      case CX88_CARD_ID_LEADTEK_WINFAST_DTV1000T:
         return (new cx_ref_dvbt(cx88conf, tunerconf, devnode, captures, error));
      /* Hauppauge WinTV-HVR-1100 (DVB-T, analog)                         */
      /* PCI SubVen ID: 0x0070, PCI SubDev ID: 0x9400 or 0x9401 or 0x9402 */
      /* Hauppauge WinTV-HVR-1100 LP (DVB-T, analog)            */
      /* PCI SubVen ID: 0x0070, PCI SubDev ID: 0x9800 or 0x9802 */
      /* Leadtek WinFast DTV2000H                     */
      /* PCI SubVen ID: 0x107d, PCI SubDev ID: 0x665e */
      case CX88_CARD_ID_WINTV_HVR1100:
      case CX88_CARD_ID_LEADTEK_WINFAST_DTV2000H:
         return (new wintv_hvr1100(cx88conf, tunerconf, devnode, captures, error));
      /* Hauppauge WinTV-HVR-1300 (DVB-T, analog)                         */
      /* PCI SubVen ID: 0x0070, PCI SubDev ID: 0x9600 or 0x9601 or 0x9602 */
      case CX88_CARD_ID_WINTV_HVR1300:
         return (new wintv_hvr1300(cx88conf, tunerconf, devnode, captures, error));
      /* Hauppauge WinTV-HVR-3000 (DVB-T, DVB-S, analog)                            */
      /* PCI SubVen ID: 0x0070, PCI SubDev ID: 0x1400 or 0x1401 or 0x1402 or 0x1404 */
      case CX88_CARD_ID_WINTV_HVR3000:
      /* Hauppauge WinTV-HVR-4000 (DVB-T, DVB-S, DVB-S2, analog)                    */
      /* PCI SubVen ID: 0x0070, PCI SubDev ID: 0x6900 or 0x6901 or 0x6902 or 0x6904 */
      case CX88_CARD_ID_WINTV_HVR4000:
         return (new wintv_hvr4000(cx88conf, tunerconf, devnode, captures, error));
      case CX88_CARD_ID_WINTV_HVR1250:
         return (new wintv_hvr1800(cx88conf, tunerconf, devnode, captures, 
            wintv_hvr1800::HVR1800_TUNER_MICROTUNE, error));
      case CX88_CARD_ID_WINTV_HVR1800:
         return (new wintv_hvr1800(cx88conf, tunerconf, devnode, captures, 
            wintv_hvr1800::HVR1800_TUNER_MICROTUNE_NXP, error));
      case CX88_CARD_ID_FUSION_7_DUAL:
         return (new fusion_7dual(cx88conf, tunerconf, devnode, captures, error));
      case CX88_CARD_ID_WINTV_HVR1850:
         return (new wintv_hvr1850(cx88conf, tunerconf, devnode, captures, error));
      default:
         return NULL;
   }
}
