/*-
 * Copyright 2010 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX23885_AVCORE_REGS_H__
#define __CX23885_AVCORE_REGS_H__

#define CX23885AV_REG_HOSTREG1               0x000
#define HOSTREG1_AUTO_INC_DISABLE            (1 << 5)
#define HOSTREG1_DIGITAL_POWERDOWN           (1 << 1)

#define CX23885AV_REG_HOSTREG2               0x001

#define CX23885AV_REG_HOSTREG3               0x002

#define CX23885AV_REG_DEVICE_ID              0x100

#define CX23885AV_REG_MISC_CONTROL           0x102
#define MISC_CONTROL_DIF_ENABLE              (1 << 7)
#define MISC_CONTROL_VID_AUTOCFG_DISABLE     (1 << 4)
#define MISC_CONTROL_DUAL_MODE_ADC2          (1 << 2)
#define MISC_CONTROL_ADC2_SELECT             (1 << 1)
#define MISC_CONTROL_SOFT_RESET              (1 << 0)

#define CX23885AV_REG_VIDEO_INPUT_CONTROL    0x103

#define CX23885AV_REG_AFE_CONTROL1           0x104
#define AFE_CONTROL_VGA_GAIN_CH2_AUDIO       (1 << 7)
#define AFE_CONTROL_VGA_GAIN_CH1_AUDIO       (1 << 6)

#define CX23885AV_REG_AFE_CONTROL2           0x105
#define AFE_CONTROL_AUDIO_ADC2               (1 << 6)
#define AFE_CONTROL_VGA_GAIN_CH3_AUDIO       (1 << 0)

#define CX23885AV_REG_AFE_CONTROL3           0x106
#define AFE_CONTROL_DROOP_COMP_CH3           (1 << 4)
#define AFE_CONTROL_DROOP_COMP_CH2           (1 << 3)
#define AFE_CONTROL_DROOP_COMP_CH1           (1 << 2)
#define AFE_CONTROL_CLAMP_ENABLE_CH3         (1 << 1)
#define AFE_CONTROL_CLAMP_ENABLE_CH2         (1 << 0)

#define CX23885AV_REG_AFE_CONTROL4           0x107

#define CX23885AV_REG_VID_PLL_COEFFICIENT    0x108

#define CX23885AV_REG_VID_PLL_POSTDIV        0x109

#define CX23885AV_REG_VID_PLL_FRACTIONAL     0x10C

#define CX23885AV_REG_AUX_PLL_COEFFICIENT    0x110

#define CX23885AV_REG_AUX_PLL_POSTDIV        0x111

#define CX23885AV_REG_AUX_PLL_REF_MULT       0x112

#define CX23885AV_REG_AUX_PLL_FRACTIONAL     0x114

#define CX23885AV_REG_SYS_PLL_COEFFICIENT    0x118

#define CX23885AV_REG_SYS_PLL_POSTDIV        0x119

#define CX23885AV_REG_SYS_PLL_FRACTIONAL     0x11C

#define CX23885AV_REG_GPIO_OEN               0x160

#define CX23885AV_REG_GPIO_IO                0x164

#define CX23885AV_REG_IR_TCD                 0x204

#define CX23885AV_REG_PLL_DIF                0x300

#define CX23885AV_REG_DIF_BYPASS             0x33C

#define CX23885AV_REG_DIF_SRC_PHASE          0x340

#define CX23885AV_REG_DIF_CONTROL            0x398

#define CX23885AV_REG_LUMA_CONTROL           0x414

#define CX23885AV_REG_CHROMA_CONTROL         0x420

#define CX23885AV_REG_DOWNLOAD_ADDRESS_LOW   0x800

#define CX23885AV_REG_DOWNLOAD_ADDRESS_HIGH  0x801

#define CX23885AV_REG_DOWNLOAD_DATA_CONTROL  0x802

#define CX23885AV_REG_DOWNLOAD_CONTROL       0x803
#define DOWNLOAD_CONTROL_MC_RUNNING          (1 << 4)
#define DOWNLOAD_CONTROL_DL_ENABLE           (1 << 3)
#define DOWNLOAD_CONTROL_AUTO_INC            (1 << 2)

#define CX23885AV_REG_AUDIO_STATUS_0         0x804
#define AUDIO_STATUS_MONO                    0x00
#define AUDIO_STATUS_STEREO                  0x01
#define AUDIO_STATUS_DUAL                    0x02
#define AUDIO_STATUS_TRIVOX                  0x04
#define AUDIO_STATUS_SAP                     0x10
#define AUDIO_STATUS_FORCED                  0xFE

#define CX23885AV_REG_AUDIO_CONTROL          0x808
#define AUDIO_CONTROL_STD_UNKNOWN            0x00
#define AUDIO_CONTROL_STD_BTSC               0x10
#define AUDIO_CONTROL_STD_EIAJ               0x20
#define AUDIO_CONTROL_STD_A2_M               0x30
#define AUDIO_CONTROL_STD_A2_BG              0x40
#define AUDIO_CONTROL_STD_A2_DK1             0x50
#define AUDIO_CONTROL_STD_A2_DK2             0x60
#define AUDIO_CONTROL_STD_A2_DK3             0x70
#define AUDIO_CONTROL_STD_A1_I               0x80
#define AUDIO_CONTROL_STD_AM_L               0x90
#define AUDIO_CONTROL_STD_NICAM_BG           0xA0
#define AUDIO_CONTROL_STD_NICAM_DK           0xB0
#define AUDIO_CONTROL_STD_NICAM_I            0xC0
#define AUDIO_CONTROL_STD_NICAM_L            0xD0
#define AUDIO_CONTROL_STD_FM_RADIO           0xE0
#define AUDIO_CONTROL_STD_AUTO               0xF0
#define AUDIO_CONTROL_MODE_MONO1             0x0
#define AUDIO_CONTROL_MODE_MONO2             0x1
#define AUDIO_CONTROL_MODE_MONO3             0x2
#define AUDIO_CONTROL_MODE_MONO4             0x3
#define AUDIO_CONTROL_MODE_STEREO            0x4
#define AUDIO_CONTROL_MODE_DUAL1             0x5
#define AUDIO_CONTROL_MODE_DUAL2             0x6
#define AUDIO_CONTROL_MODE_DUAL3             0x7
#define AUDIO_CONTROL_MODE_DUAL4             0x8
#define AUDIO_CONTROL_MODE_DUAL5             0x9
#define AUDIO_CONTROL_MODE_SAP               0xA
#define AUDIO_CONTROL_SYSTEM_BG              0x0
#define AUDIO_CONTROL_SYSTEM_DK1             0x1
#define AUDIO_CONTROL_SYSTEM_DK2             0x2
#define AUDIO_CONTROL_SYSTEM_DK3             0x3
#define AUDIO_CONTROL_SYSTEM_I               0x4
#define AUDIO_CONTROL_SYSTEM_L               0x5
#define AUDIO_CONTROL_SYSTEM_BTSC            0x6
#define AUDIO_CONTROL_SYSTEM_EIAJ            0x7
#define AUDIO_CONTROL_SYSTEM_A2_M            0x8
#define AUDIO_CONTROL_SYSTEM_FM              0xA
#define AUDIO_CONTROL_SYSTEM_AUTO            0xF

#define CX23885AV_REG_PREFERRED_MODE         0x809
#define AUDIO_MODE_FM_DEVIATION_NORMAL       0x00
#define AUDIO_MODE_FM_DEVIATION_HIGH         0x40
#define AUDIO_MODE_FM_DEVIATION_VERY_HIGH    0x80
#define AUDIO_MODE_DEEMPHASIS_50             (1 << 5)
#define AUDIO_MODE_MUTE_NO_PREF              (1 << 4)
#define AUDIO_MODE_PREF_MONO                 0x0
#define AUDIO_MODE_PREF_LANGUAGE_B           0x1
#define AUDIO_MODE_PREF_LANGUAGE_C           0x2
#define AUDIO_MODE_PREF_FALLBACK             0x3
#define AUDIO_MODE_PREF_STEREO               0x4
#define AUDIO_MODE_PREF_LANGUAGE_AC          0x5
#define AUDIO_MODE_PREF_LANGUAGE_BC          0x6
#define AUDIO_MODE_PREF_LANGUAGE_AB          0x7

#define CX23885AV_REG_AUDIO_FORMAT_CTL       0x80B
#define AUDIO_FORMAT_TUNER_OUTPUT_AF         (1 << 5)
#define AUDIO_FORMAT_6_5MHZ_DK               0x00
#define AUDIO_FORMAT_6_5MHZ_L                0x08
#define AUDIO_FORMAT_6_5MHZ_AUTO             0x10
#define AUDIO_FORMAT_4_5MHZ_CHROMA           0x0
#define AUDIO_FORMAT_4_5MHZ_BTSC             0x1
#define AUDIO_FORMAT_4_5MHZ_EIAJ             0x2
#define AUDIO_FORMAT_4_5MHZ_A2_M             0x3
#define AUDIO_FORMAT_4_5MHZ_AUTO             0x4

#define CX23885AV_REG_PATH1_AUDIO_SEL_CTL    0x8D0
#define CX23885AV_REG_PATH2_AUDIO_SEL_CTL    0x8E0
#define AUDIO_SEL_CTL_DEMOD_MAIN             0x0
#define AUDIO_SEL_CTL_DEMOD_SUB              0x1
#define AUDIO_SEL_CTL_I2S                    0x2
#define AUDIO_SEL_CTL_AC97                   0x3

#define CX23885AV_REG_PATH1_MUTE_CONTROL     0x8D3
#define MUTE_CONTROL_AC97_MUTE               (1 << 4)
#define MUTE_CONTROL_ANC_MUTE                (1 << 3)
#define MUTE_CONTROL_SERIAL_MUTE             (1 << 2)
#define CX23885AV_REG_PATH2_MUTE_CONTROL     0x8E3
#define MUTE_CONTROL_SRC_MUTE                (1 << 1)
#define MUTE_CONTROL_SOFT_MUTE               (1 << 0)

#define CX23885AV_REG_PATH1_VOLUME           0x8D4
#define CX23885AV_REG_PATH2_VOLUME           0x8E4

#define CX23885AV_REG_PATH1_BALANCE          0x8D5
#define CX23885AV_REG_PATH2_BALANCE          0x8E5
#define BALANCE_LEFT                         (1 << 7)

#define CX23885AV_REG_OUTPUT_SRC_SEL         0x910
#define OUTPUT_SRC_MASK                      0x3
#define OUTPUT_SRC3                          0
#define OUTPUT_SRC4                          1
#define OUTPUT_SRC5                          2
#define OUTPUT_SRC6                          3
#define OUTPUT_SRC_AC97_SHIFT                6
#define OUTPUT_SRC_I2S_SHIFT                 4
#define OUTPUT_SRC_PAR2_SHIFT                2
#define OUTPUT_SRC_PAR1_SHIFT                0

#define CX23885AV_REG_INPUT_SRC_SEL1         0x912
#define INPUT_SRC_MASK                       0xF
#define INPUT_SRC_PATH1                      (0 << 2)
#define INPUT_SRC_PATH2                      (1 << 2)
#define INPUT_SRC_STEREO                     (2 << 2)
#define INPUT_SRC_MONO                       (3 << 2)
#define INPUT_SRC_CLK_I2S                    0
#define INPUT_SRC_CLK_AC97                   1
#define INPUT_SRC_CLK_NICAM                  2
#define INPUT_SRC_CLK_FIFO                   3
#define INPUT_SRC4_SHIFT                     4
#define INPUT_SRC3_SHIFT                     0

#define CX23885AV_REG_I2S_INPUT_CTL1         0x914
#define I2S_INPUT_CTL_SONY                   (1 << 7)

#define CX23885AV_REG_I2S_INPUT_CTL2         0x915
#define I2S_INPUT_CTL_MASTER                 (1 << 0)

#define CX23885AV_REG_I2S_OUTPUT_CTL1        0x918
#define I2S_OUTPUT_CTL_SONY                  (1 << 7)

#define CX23885AV_REG_I2S_OUTPUT_CTL2        0x919
#define I2S_OUTPUT_CTL_MASTER                (1 << 0)

#endif
